# winwin

## 安装说明

```

pip install winwin
pip install winwin -i http://sys-3007.zhidou.hz:19900/simple/ --trusted-host sys-3007.zhidou.hz

pip install git+http://{USER}:{PASSWORD}@git.yikuaigao.com/zhaobin/winwin.git
```

## 使用说明

```
import winnwin
winwin.__version__
```